@@ -140,8 +140,10 @@ void debug_handler()
 	if (new_gdb4()) /* (PW)28AUG91: test for gdb 4.0 */
 		{
 		/* (SH) for gdb 4.0 */
+#ifndef NeXT
 	    query_gdb("set height 0\n",		PARSE_OFF | ECHO_OFF | FILTER_OFF);	
 	    query_gdb("set width 0\n", 		PARSE_OFF | ECHO_OFF | FILTER_OFF);
+#endif
     	query_gdb("set p pretty on\n",	PARSE_OFF | ECHO_OFF | FILTER_OFF);
     	query_gdb("set confirm off\n",	PARSE_OFF | ECHO_OFF | FILTER_OFF);
 		}
@@ -711,14 +713,14 @@ void query_gdb_directories()
 |			  (see comments on query_gdb_directories() above).				|
 |																			|
 |	(PW)(DS)19FEB92 NeXT :													|
-|	gdb 3.1 for the NeXT does not answer 'undefined command' when			|
+|	gdb 3.1 for the NeXT OS 2.1 does not answer 'undefined command' when	|
 |	trying to execute 'show'. That is why the test for gdb-4.x vs 			|
 |	gdb 3.x does not work in case of NeXT. Using gdb 3.x as default			|
 |	will make xxgdb skip this test.											|
 |	The gdb answer is "Ambiguous command "show": shownops, showps.".		|
 |																			|
 +--------------------------------------------------------------------------*/
-#ifdef NeXT
+#if defined(NeXT) && defined(NEXTOS_2)
 static int new_gdb = False;			/* special case for NeXT */
 #else
 static int new_gdb = True;			/* default : we are running gdb 4.0 */
