@@ -280,6 +280,13 @@
     instead of
     	\\(\\([0-9]+:.*\n\\)*\\)
     for display pattern.
+
+	(PW)21APR95 :For gdb 4.14 (Sun) :
+	\032\032/net/tcela/sky/aoutwrap/sun/../aoutwrap.c:714:21758:beg:125f0
+                                                                    ^^^^^
+	So change :0.+\n into :.+\n for exec patterns and up/down pattern.
+	It is now possible that those new patterns works also for NeXT, but I
+	cannot test so I will leave the ifdef NexT.
     */
     
 
@@ -287,17 +294,17 @@ static PatternRec output_pattern[] = {
 
 #ifndef NeXT  /* if standard GDB */
     /* exec with Message after */
-    {"\\(.*\n\\)*\032\032\\([^ \n]+\\):\\([0-9]+\\):\\([0-9]+\\):\\([^ \n]+\\):0.+\n\\([ ]*[^0-9\n].*\n\\)\\(\\([0-9]+:.*\n\\(\\( .*\n\\)*[ }]*}\n\\)?\\)*\\)",
+    {"\\(.*\n\\)*\032\032\\([^ \n]+\\):\\([0-9]+\\):\\([0-9]+\\):\\([^ \n]+\\):.+\n\\([ ]*[^0-9\n].*\n\\)\\(\\([0-9]+:.*\n\\(\\( .*\n\\)*[ }]*}\n\\)?\\)*\\)",
      NULL,
      {6, -1, -1, 3, 2, 7}
     },
     /* exec with Message before */
-    {"\\(.*\n\\)*\\([ ]*[^ \n].*\n\\)\032\032\\([^ \n]+\\):\\([0-9]+\\):\\([0-9]+\\):\\([^ \n]+\\):0.+\n\\(\\([0-9]+:.*\n\\(\\( .*\n\\)*[ }]*}\n\\)?\\)*\\)",
+    {"\\(.*\n\\)*\\([ ]*[^ \n].*\n\\)\032\032\\([^ \n]+\\):\\([0-9]+\\):\\([0-9]+\\):\\([^ \n]+\\):.+\n\\(\\([0-9]+:.*\n\\(\\( .*\n\\)*[ }]*}\n\\)?\\)*\\)",
      NULL,
      {2, -1, -1, 4, 3, 7}	
     },
     /* exec without Message */
-    {"\\(.*\n\\)*\032\032\\(\\([^ \n]+\\):\\([0-9]+\\):\\([0-9]+\\):\\([^ \n]+\\):0.+\n\\)\\(\\([0-9]+:.*\n\\(\\( .*\n\\)*[ }]*}\n\\)?\\)*\\)",
+    {"\\(.*\n\\)*\032\032\\(\\([^ \n]+\\):\\([0-9]+\\):\\([0-9]+\\):\\([^ \n]+\\):.+\n\\)\\(\\([0-9]+:.*\n\\(\\( .*\n\\)*[ }]*}\n\\)?\\)*\\)",
      NULL,
      {2, -1, -1, 4, 3, 7}
     },
@@ -325,11 +332,29 @@ static PatternRec output_pattern[] = {
      NULL,
      {-1, -1, -1, -1, -1, -1}
     },
+#if defined (NeXT) && !defined(NEXTOS_2)
+#if defined(NEXTOS_3_0)
+	/* NeXT 3.0 gdb is special case : uses "file:#" intead of "file, line #" */
+      /* break */
+    {"\\(.*\n\\)*Breakpoint \\([0-9]+\\) at [^ \n]+: file \\([^ \n]+\\):\\([0-9]+\\).\n",
+     NULL,
+     {-1, 2, -1, 4, 3, -1}
+    },
+#else
+	/* NeXT 3.X gdb is special case : leaves out "file" label altogether */
+    /* break */
+    {"\\(.*\n\\)*Breakpoint \\([0-9]+\\) at [^ \n]+: \\([^ \n]+\\):\\([0-9]+\\).\n",
+     NULL,
+     {-1, 2, -1, 4, 3, -1}
+    },
+#endif
+#else    /* if standard GDB */
     /* break */
     {"\\(.*\n\\)*Breakpoint \\([0-9]+\\) at [^ \n]+: file \\([^ \n]+\\), line \\([0-9]+\\).\n",
      NULL,
      {-1, 2, -1, 4, 3, -1}
     },
+#endif /* NeXT */
     /* info directories */
     {"Source directories searched:[ ]*\\([^ \n]+\\)[ ]*\n",
      NULL,
@@ -339,7 +364,7 @@ static PatternRec output_pattern[] = {
     
 #ifndef NeXT  /* if standard GDB */
     /* up, down */
-    {"\\(.*\n\\)*\\(#[0-9]+[ ]+\\(0[^ \n]+[ ]+in[ ]+\\)?\\([^ \n]+\\)[^\032]*\\)\032\032\\([^ \n]+\\):\\([0-9]+\\):\\([0-9]+\\):\\([^ \n]+\\):0.+\n",
+    {"\\(.*\n\\)*\\(#[0-9]+[ ]+\\(0[^ \n]+[ ]+in[ ]+\\)?\\([^ \n]+\\)[^\032]*\\)\032\032\\([^ \n]+\\):\\([0-9]+\\):\\([0-9]+\\):\\([^ \n]+\\):.+\n",
      NULL,
      {2, -1, 4, 6, 5, -1}	
     },
